using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using DotNetNuke;
using DotNetNuke.Common.Utilities;
using DotNetNuke.Entities.Modules;
using DotNetNuke.Services.Search;

namespace YourCompany.FBFanboxDNN.Components
{
    public class FBFanboxDNNController : ISearchable, IPortable
    {

        #region public method

        /// <summary>
        /// Gets all the FBFanboxDNNInfo objects for items matching the this moduleId
        /// </summary>
        /// <param name="moduleId"></param>
        /// <returns></returns>
        public List<FBFanboxDNNInfo> GetFBFanboxDNNs(int moduleId)
        {
            return CBO.FillCollection<FBFanboxDNNInfo>(DataProvider.Instance().GetFBFanboxDNNs(moduleId));
        }

        /// <summary>
        /// Get an info object from the database
        /// </summary>
        /// <param name="moduleId"></param>
        /// <param name="itemId"></param>
        /// <returns></returns>
        public FBFanboxDNNInfo GetFBFanboxDNN(int moduleId, int itemId)
        {
            return (FBFanboxDNNInfo)CBO.FillObject(DataProvider.Instance().GetFBFanboxDNN(moduleId, itemId), typeof(FBFanboxDNNInfo));
        }


        /// <summary>
        /// Adds a new FBFanboxDNNInfo object into the database
        /// </summary>
        /// <param name="info"></param>
        public void AddFBFanboxDNN(FBFanboxDNNInfo info)
        {
            //check we have some content to store
            if (info.Content != string.Empty)
            {
                DataProvider.Instance().AddFBFanboxDNN(info.ModuleId, info.Content, info.CreatedByUser);
            }
        }

        /// <summary>
        /// update a info object already stored in the database
        /// </summary>
        /// <param name="info"></param>
        public void UpdateFBFanboxDNN(FBFanboxDNNInfo info)
        {
            //check we have some content to update
            if (info.Content != string.Empty)
            {
                DataProvider.Instance().UpdateFBFanboxDNN(info.ModuleId, info.ItemId, info.Content, info.CreatedByUser);
            }
        }


        /// <summary>
        /// Delete a given item from the database
        /// </summary>
        /// <param name="moduleId"></param>
        /// <param name="itemId"></param>
        public void DeleteFBFanboxDNN(int moduleId, int itemId)
        {
            DataProvider.Instance().DeleteFBFanboxDNN(moduleId, itemId);
        }


        #endregion

        #region ISearchable Members

        /// <summary>
        /// Implements the search interface required to allow DNN to index/search the content of your
        /// module
        /// </summary>
        /// <param name="modInfo"></param>
        /// <returns></returns>
        public DotNetNuke.Services.Search.SearchItemInfoCollection GetSearchItems(ModuleInfo modInfo)
        {
            SearchItemInfoCollection searchItems = new SearchItemInfoCollection();

            List<FBFanboxDNNInfo> infos = GetFBFanboxDNNs(modInfo.ModuleID);

            foreach (FBFanboxDNNInfo info in infos)
            {
                SearchItemInfo searchInfo = new SearchItemInfo(modInfo.ModuleTitle, info.Content, info.CreatedByUser, info.CreatedDate,
                                                    modInfo.ModuleID, info.ItemId.ToString(), info.Content, "Item=" + info.ItemId.ToString());
                searchItems.Add(searchInfo);
            }

            return searchItems;
        }

        #endregion

        #region IPortable Members

        /// <summary>
        /// Exports a module to xml
        /// </summary>
        /// <param name="ModuleID"></param>
        /// <returns></returns>
        public string ExportModule(int moduleID)
        {
            StringBuilder sb = new StringBuilder();

            List<FBFanboxDNNInfo> infos = GetFBFanboxDNNs(moduleID);

            if (infos.Count > 0)
            {
                sb.Append("<FBFanboxDNNs>");
                foreach (FBFanboxDNNInfo info in infos)
                {
                    sb.Append("<FBFanboxDNN>");
                    sb.Append("<content>");
                    sb.Append(XmlUtils.XMLEncode(info.Content));
                    sb.Append("</content>");
                    sb.Append("</FBFanboxDNN>");
                }
                sb.Append("</FBFanboxDNNs>");
            }

            return sb.ToString();
        }

        /// <summary>
        /// imports a module from an xml file
        /// </summary>
        /// <param name="ModuleID"></param>
        /// <param name="Content"></param>
        /// <param name="Version"></param>
        /// <param name="UserID"></param>
        public void ImportModule(int ModuleID, string Content, string Version, int UserID)
        {
            XmlNode infos = DotNetNuke.Common.Globals.GetContent(Content, "FBFanboxDNNs");

            foreach (XmlNode info in infos.SelectNodes("FBFanboxDNN"))
            {
                FBFanboxDNNInfo FBFanboxDNNInfo = new FBFanboxDNNInfo();
                FBFanboxDNNInfo.ModuleId = ModuleID;
                FBFanboxDNNInfo.Content = info.SelectSingleNode("content").InnerText;
                FBFanboxDNNInfo.CreatedByUser = UserID;

                AddFBFanboxDNN(FBFanboxDNNInfo);
            }
        }

        #endregion
    }
}
